import axios from 'axios';

interface ITutorialData {
  paymentId: number;
  paymentCode: string;
  paymentMethod: string;
}

type CUSTOMER = {
  first_name: string;
  last_name: string;
  email: string;
  phone: string;
  address: string;
};

type CARD_ITEM = {
  name: string;
  price: number;
  quantity: number;
};

interface IRequestData {
  payment_method_id: number;
  cartTotal: number;
  currency: string;
  customer: CUSTOMER;
  cartItems: Array<CARD_ITEM>;
}

const APIURL = 'http://st1.fawaterk.com:8181/api/v2';

const instanceAPI = axios.create({
  baseURL: APIURL,
});

instanceAPI.interceptors.request.use(
  (config) => {
    if (config.method === 'post' && config.data === undefined) {
      config.data = {};
    }
    return config;
  },
  (error) => Promise.reject(error)
);

export const getInvoicePaymentTypes = async (TOKEN: string) => {
  const result = await instanceAPI.post<Array<ITutorialData>>(
    '/invoice/paymentType',
    {},
    {
      headers: {
        Authorization: `Bearer ${TOKEN}`,
      },
    }
  );
  return result.data;
};

export const createInvoiceRequest = async (
  requestUrl: string,
  requestData: IRequestData
) => {
  return new Promise(async (resolve, reject) => {
    try {
      const result = await instanceAPI.post(requestUrl, requestData, {});
      resolve(result.data);
    } catch (err) {
      reject({
        status: 'error',
        message: null,
      });
    }
  });
};
